==> haskell-authenticate-oauth-1.7-367.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-4SD3yD7HUOCEjZvrpICN2l
key:                  authenticate-oauth-1.7-4SD3yD7HUOCEjZvrpICN2l
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  6d45f2a091b572c4193a4574e1c8a421
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-4SD3yD7HUOCEjZvrpICN2l
depends:
    RSA-2.4.1-JmsPyfqrInc4jyXQicqwhl SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    base-4.18.2.1 base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    crypto-pubkey-types-0.4.3-FJtMwIK4cJXEyUUz4Hc1UZ
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    http-client-0.7.19-76DosIrYZ8GJOiYGyhGmc9
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.7-368-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-LVfJbbsaaAM8EUlBSEN0UV
key:                  authenticate-oauth-1.7-LVfJbbsaaAM8EUlBSEN0UV
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  aede155fbf09a967ecf3990500e4112b
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-LVfJbbsaaAM8EUlBSEN0UV
depends:
    RSA-2.4.1-JmsPyfqrInc4jyXQicqwhl SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    base-4.18.2.1 base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    crypto-pubkey-types-0.4.3-FJtMwIK4cJXEyUUz4Hc1UZ
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
